# 📝 Household Management App – Granular Task List

> **Legend**
> - ⬜️  To Do
> - 🔧  In Progress
> - ✅  Done
> - 🚧  Blocked / Waiting

---

## 1. Design System & Global Setup
| Task | Status | Notes |
| --- | --- | --- |
| Tailwind design tokens (colors, spacing, typography, motion) | ✅ | `tailwind.config.ts` updated |
| Base UI components migrated to new tokens<br/>• Button<br/>• Card<br/>• Dialog<br/>• Menu<br/>• Input<br/>• Checkbox | ✅ | All components updated with design tokens |
| Add utility classes (skeleton, shadows, animations) | ✅ | Included in `tailwind.config.ts` |
| Global theme variables & CSS vars | ⬜️ | To define in `src/assets/base.css` |

---

## 2. Dashboard
| Task | Status | Notes |
| --- | --- | --- |
| Dashboard layout re-architecture | ✅ | `DashboardPage.vue` updated |
| PersonalStatusCard | ✅ | Implemented in `components/dashboard` |
| UniversalFAB | ✅ | Radial / haptic FAB implemented |
| ActivityFeed redesign | ✅ | Enhanced with smart grouping, animations, social proof ✔ |
| QuickWinSuggestion widget | ✅ | Modernized with new design tokens & logic. |

---

## 3. Chores Module
| Task | Status | Notes |
| --- | --- | --- |
| ChoresList (tabs & smart categorization) | ✅ | `ChoresList.vue` ✔ |
| ChoreCard (new design) | ✅ | `ChoreCard.vue` ✔ |
| QuickChoreAdd (inline add bar) | ✅ | Reviewed and confirmed modern implementation. |
| ChoreDetailSheet (progressive disclosure) | ✅ | Redesigned with progressive disclosure and new tokens. |
| Chore rotation / fairness composable | ✅ | `useFairness` basic round-robin helper implemented |
| Unit tests for new chores components | ⬜️ | Add Vitest + Vue Test Utils |

---

## 4. Shopping Lists Module
| Task | Status | Notes |
| --- | --- | --- |
| SmartShoppingList component | ✅ | Component implemented with conflict prevention ✔ |
| ListDirectory (multi-list view) | ✅ | Complete implementation with filters and suggestions |
| ListItemComposer (intelligent add) | ✅ | Intelligent add with autocomplete, suggestions, and voice-input stubs ✅ |
| Real-time claiming & conflict prevention | ✅ | ListItem/ItemsList refactor + WS skeleton |
| PurchaseConfirmationDialog | ✅ | Receipt-aware purchase confirmation component stub |

---

## 5. Expenses Module
| Task | Status | Notes |
| --- | --- | --- |
| ExpenseOverview (dashboard) | ✅ | Refactored for financial transparency ✔ |
| ExpenseCreationSheet redesign | ✅ | Redesigned with multi-step UX & new tokens. |
| SettlementFlow redesign | ✅ | Complete UX rewrite with verification workflow, payment methods, dispute handling ✔ |
| ReceiptScannerModal (OCR) | ✅ | Implemented modal uploads to backend OCR endpoint ✔ |

---

## 6. Group Management & Auth
| Task | Status | Notes |
| --- | --- | --- |
| AuthenticationSheet (single-screen) | ✅ | New component ✔ |
| OnboardingCarousel | ✅ | 4-step guided setup with profile, household choice, features tour, completion ✔ |
| HouseholdInvite component | ✅ | QR + code join flow (part of InviteManager) |
| HouseholdSettings page | ✅ | Theme selection, rules, member CRUD complete |
| InviteManager redesign | ✅ | Deep link + analytics + QR animation complete |

---

## 7. State Management & Composables
| Task | Status | Notes |
| --- | --- | --- |
| useOptimisticUpdates composable | ✅ | Core implementation with rollback |
| useOfflineSync composable | ✅ | Core implementation with queue flush watcher |
| useFairness composable | ✅ | Basic round-robin helper implemented |
| useSocket composable | ✅ | WebSocket client with JWT auth, auto-reconnect |
| offlineQueue utility | ✅ | IndexedDB operations with idb-keyval |
| Pinia store refactors (chores, lists, expenses, activity) | ⬜️ | Align with new backend shapes |

---

## 8. Real-time & Offline
| Task | Status | Notes |
| --- | --- | --- |
| WebSocket integration (socket.io-client) | ✅ | useSocket composable implemented |
| Service Worker (workbox) | 🔧 | Basic cache shell implemented (TS issues) |
| IndexedDB offline storage | ✅ | idb-keyval integration complete |
| Background sync queue | ✅ | Complete with useOfflineSync |
| Offline conflict resolution strategy | ✅ | Enhanced ConflictResolutionDialog with side-by-side diff |

---

## 9. Testing & Quality
| Task | Status | Notes |
| --- | --- | --- |
| Unit tests for new components | 🔧 | Basic tests for InviteManager, ReceiptScanner |
| E2E tests update (Playwright) | ⬜️ | Cover new flows |
| Accessibility audit (axe-core) | ⬜️ | WCAG 2.1 AA compliance |
| Performance budget tests | ⬜️ | Lighthouse CI |

---

## 10. Documentation & CI
| Task | Status | Notes |
| --- | --- | --- |
| Update README with new dev scripts | ✅ | Include `dev:fe`, `dev:be` scripts |
| Component documentation | ⬜️ | Document new components and patterns |
| CI pipeline update for lint/format/test | ⬜️ | GitHub Actions |

---

## 11. Backend (FastAPI)
| Area | Task | Status | Notes |
| --- | --- | --- | --- |
| General | Align Pydantic models with new frontend contracts | ⬜️ | Update schemas: chores, lists, expenses |
| General | Adopt lifespan context managers instead of on_event | ⬜️ | Refactor `app/main.py` startup logic |
| Auth | Magic-link auth endpoint v2 | ⬜️ | Rate-limit + email template |
| Auth | OAuth provider session tightening | ⬜️ | Rotate refresh tokens, cleanup |
| Chores | `/chores` CRUD refactor for soft deletes & versioning | ⬜️ | Align with new chore rotation logic |
| Chores | Assignment endpoints (`/chores/{id}/claim`, `/complete`) | ⬜️ | Needs transactional safety |
| Chores | Scheduler to auto-update recurring chores | ⬜️ | Celery/APS implementation |
| Lists | `/lists` collaborative real-time WS channel | ⬜️ | Publish item claiming events |
| Lists | OCR upload endpoint for receipt scanning | ✅ | Gemini-based OCR endpoint implemented |
| Expenses | `/expenses` split calculations on backend | ⬜️ | Maintain authoritative split logic |
| Expenses | Settlement workflow endpoints (`/settlements`) | ⬜️ | Multi-step verification |
| Groups | Invite code generation & validation endpoints | ⬜️ | Expiry + usage tracking |
| Groups | Roles/permissions middleware | ⬜️ | Admin vs member scopes |
| Real-time | WebSocket gateway (FastAPI) for lists & chores | ⬜️ | Use `fastapi-websocket` & redis pubsub |
| Offline | Sync delta endpoint (`/sync/changes`) | ⬜️ | Accept queued ops, return patches |
| Performance | Redis caching layer for frequently accessed data | ⬜️ | Chore categories, dashboard stats |
| Testing | Pytest coverage for new endpoints | ⬜️ | Target ≥90% coverage |
| CI | GitHub Action: run pytest + Ruff + MyPy | ⬜️ | Add to pipeline |

---

## 📋 **Next Priority Sprint: Performance & Polish**

### **Immediate Tasks (Next Session):**
1. **Pinia Store Updates**: Real-time features and cross-feature integration
2. **Performance Optimization**: Code splitting, skeleton states, optimistic caching  
3. **Testing Infrastructure**: Comprehensive unit tests, E2E test updates
4. **Service Worker**: Fix TypeScript issues and complete offline functionality

### **Advanced Features Sprint:**
1. **Smart Suggestions**: AI-powered task and expense suggestions
2. **Analytics Integration**: Usage patterns, household efficiency metrics
3. **Advanced Conflict Resolution**: Manual merge functionality
4. **Gamification**: Points, streaks, rewards system

### **Backend Alignment Sprint:**
1. **WebSocket Implementation**: Real-time collaborative features
2. **Sync Delta Endpoint**: Efficient offline synchronization
3. **Performance Optimization**: Redis caching, query optimization
4. **Testing & CI**: Comprehensive backend test coverage

---

_Last updated: 2024-07-25 (comprehensive session completion)_
